gam-terms 0.3.127

Smooth-term basis construction and penalty assembly for the gam penalized-likelihood engine
docs.rs failed to build gam-terms-0.3.127
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Visit the last successful build: gam-terms-0.3.128