pub struct BasisOptions {
pub derivative_order: usize,
pub basis_family: BasisFamily,
}Expand description
Options for basis generation, controlling derivative order.
Fields
derivative_order: usizeDerivative order: 0 = value (default), 1 = first derivative, 2 = second derivative
basis_family: BasisFamilyBasis family to evaluate.
Implementations
Sourceimpl BasisOptions
impl BasisOptions
Sourcepub const fn first_derivative() -> Self
pub const fn first_derivative() -> Self
Create options for evaluating first derivatives of basis functions.
Sourcepub const fn second_derivative() -> Self
pub const fn second_derivative() -> Self
Create options for evaluating second derivatives of basis functions.