Module geometry

Module geometry 

Structs

PeeledHull
A peeled convex hull represented as an intersection of half-spaces a^T x <= b. Facet normals a are unit-length direction vectors used to generate supporting halfspaces after iterative peeling. This is a robust, outlier-insensitive boundary representation.