pub enum BasisNullGeometryScaleLaw {
PolynomialPullback,
CyclicConstantMode,
TensorProductPullback,
EuclideanPolynomialPullback,
CenterConstraintPullback,
MeasureJetAffineHeadPullback,
IntrinsicHarmonicSubspace,
ConstantCurvatureCenterConstraint,
PcaScoreCongruence,
FullRankRandomEffect,
ReplicatedInner,
}Expand description
Transformation of the structural penalty null space / identifiability section. This is explicit because equal penalty ranks alone do not prove that the same unpenalized functions survived a coordinate change.
Variants
PolynomialPullback
CyclicConstantMode
TensorProductPullback
EuclideanPolynomialPullback
CenterConstraintPullback
MeasureJetAffineHeadPullback
IntrinsicHarmonicSubspace
ConstantCurvatureCenterConstraint
PcaScoreCongruence
FullRankRandomEffect
ReplicatedInner