pub struct SmoothDesign {
pub term_designs: Vec<DesignMatrix>,
pub penalties: Vec<BlockwisePenalty>,
pub nullspace_dims: Vec<usize>,
pub penaltyinfo: Vec<PenaltyBlockInfo>,
pub dropped_penaltyinfo: Vec<DroppedPenaltyBlockInfo>,
pub terms: Vec<SmoothTerm>,
pub coefficient_lower_bounds: Option<Array1<f64>>,
pub linear_constraints: Option<LinearInequalityConstraints>,
}Fields
term_designs: Vec<DesignMatrix>penalties: Vec<BlockwisePenalty>Per-term block-local penalties. Each col_range is relative to the
smooth block (i.e. indexing into the concatenation of term_designs).
nullspace_dims: Vec<usize>penaltyinfo: Vec<PenaltyBlockInfo>dropped_penaltyinfo: Vec<DroppedPenaltyBlockInfo>terms: Vec<SmoothTerm>coefficient_lower_bounds: Option<Array1<f64>>Optional smooth-block lower bounds in smooth coefficient coordinates.
Length equals total_smooth_cols() when present.
linear_constraints: Option<LinearInequalityConstraints>Optional smooth-block inequality constraints:
A_smooth * beta_smooth >= b.
Implementations
Sourceimpl SmoothDesign
impl SmoothDesign
Sourceimpl SmoothDesign
impl SmoothDesign
Sourcepub fn map_term_coefficients(
unconstrained: &Array1<f64>,
shape: ShapeConstraint,
) -> Result<Array1<f64>, BasisError>
pub fn map_term_coefficients( unconstrained: &Array1<f64>, shape: ShapeConstraint, ) -> Result<Array1<f64>, BasisError>
Map an unconstrained term coefficient vector to its constrained shape space. This is useful for nonlinear fits that optimize unconstrained parameters.